@@ -1,18 +1,18 @@
-/* $Id: DBIXS.h,v 1.41 1997/07/18 12:44:09 timbo Exp $
+/* $Id: DBIXS.h,v 1.43 1997/09/05 19:16:40 timbo Exp $
  *
- * Copyright (c) 1994, 1995 Tim Bunce
+ * Copyright (c) 1994, 1995, 1996, 1997  Tim Bunce  England
  *
- * You may distribute under the terms of either the GNU General Public
- * License or the Artistic License, as specified in the Perl README file.
+ * See COPYRIGHT section in DBI.pm for usage and distribution rights.
  */
 
 /* DBI Interface Definitions for DBD Modules */
 
 /* first pull in the standard Perl header files for extensions */
-#include "EXTERN.h"
-#include "perl.h"
-#include "XSUB.h"
+#include <EXTERN.h>
+#include <perl.h>
+#include <XSUB.h>
 
+#include "dbi_sql.h"
 
 /* The DBIXS_VERSION value will be incremented whenever new code is
  * added to the interface (this file) or significant changes are made.
@@ -33,46 +33,6 @@ error You_need_to_upgrade_your_DBI_module_before_building_this_driver.
 #endif
 
 
-/* Some core SQL CLI standard (ODBC) declarations		*/
-#ifndef SQL_SUCCESS	/* don't clash with ODBC based drivers	*/
-
-/* Standard SQL datatypes (ANSI/ODBC type numbering)		*/
-#define	SQL_CHAR		1	/*	DBI_CHAR 	*/
-#define	SQL_NUMERIC		2
-#define	SQL_DECIMAL		3
-#define	SQL_INTEGER		4	/*	DBI_INTEGER	*/
-#define	SQL_SMALLINT		5
-#define	SQL_FLOAT		6	/*	DBI_FLOAT	*/
-#define	SQL_REAL		7
-#define	SQL_DOUBLE		8
-#define	SQL_VARCHAR		12	/*	DBI_VARCHAR	*/
-
-#ifdef just_for_pondering /* not used yet, just here for pondering */
-#define SQL_DATE           9
-#define SQL_TIME           10
-#define SQL_TIMESTAMP      11
-#define SQL_LONGVARCHAR    (-1)
-#define SQL_BINARY         (-2)
-#define SQL_VARBINARY      (-3)
-#define SQL_LONGVARBINARY  (-4)
-#define SQL_BIGINT         (-5)
-#define SQL_TINYINT        (-6)
-#endif
-
-/* Main return codes						*/
-#define	SQL_ERROR			(-1)
-#define	SQL_SUCCESS			0
-#define	SQL_SUCCESS_WITH_INFO		1
-#define	SQL_NO_DATA_FOUND		100
-
-#endif	/*	SQL_SUCCESS	*/
-
-/* Handy macro for testing for success and success with info.		*/
-/* BEWARE that this macro can have side effects since rc appears twice!	*/
-/* So DONT use it as if(SQL_ok(func(...))) { ... }			*/
-#define SQL_ok(rc)	((rc)==SQL_SUCCESS || (rc)==SQL_SUCCESS_WITH_INFO)
-
-
 /* forward declaration of 'DBI Handle Common Data', see below		*/
 
 /* implementor needs to define actual struct { dbih_??c_t com; ... }*/
@@ -96,7 +56,7 @@ typedef struct imp_xxh_st imp_xxh_t;	/* any (defined below)		*/
 
 typedef struct dbih_com_std_st {
     U32  flags;		/* XXX will change to U32 at some point		*/
-    U16  call_depth;	/* used by DBI to track nested calls		*/
+    int  call_depth;/* used by DBI to track nested calls (int)	*/
     U16  type;		/* DBIt_DR, DBIt_DB, DBIt_ST			*/
     SV   *my_h;		/* copy of owner inner handle (NO r.c.inc)	*/
     SV   *parent_h;	/* parent inner handle (RV(HV)) (r.c.inc)	*/
@@ -318,7 +278,7 @@ typedef struct {		/* -- FIELD DESCRIPTOR --		*/
 
 typedef struct {
 
-#define DBISTATE_VERSION  9	/* Must change whenever dbistate_t does	*/
+#define DBISTATE_VERSION  10	/* Must change whenever dbistate_t does	*/
 
     /* this must be the first member in structure			*/
     void (*check_version) _((char *name, int dbis_cv, int dbis_cs, int need_dbixs_cv));
@@ -337,16 +297,21 @@ typedef struct {
     imp_xxh_t * (*getcom)	_((SV *h));	/* see DBIh_COM macro	*/
     void        (*clearcom)	_((imp_xxh_t *imp_xxh));
     SV        * (*event)	_((SV *h, char *name, SV*, SV*));
-    int         (*set_attr)	_((SV *h, SV *keysv, SV *valuesv));
-    SV        * (*get_attr)	_((SV *h, SV *keysv));
+    int         (*set_attr_k)	_((SV *h, SV *keysv, int dbikey, SV *valuesv));
+    SV        * (*get_attr_k)	_((SV *h, SV *keysv, int dbikey));
     AV        * (*get_fbav)	_((imp_sth_t *imp_sth));
     SV        * (*make_fdsv)	_((SV *sth, char *imp_class, STRLEN imp_size, char *col_name));
     int         (*bind_as_num)	_((int sql_type, int p, int s));
-    U32         (*hash)		_((char *string, long i));
+    int         (*hash)		_((char *string, long i));
+    AV        * (*preparse)	_((SV *sth, char *statement, U32 flags, U32 spare));
 
     void *pad[10];
 } dbistate_t;
 
+/* macros for backwards compatibility */
+#define set_attr(h, k, v)	set_attr_k(h, k, 0, v)
+#define get_attr(h, k)		get_attr_k(h, k, 0)
+
 #ifndef DBIS
 #define DBIS              dbis /* default name for dbistate_t variable	*/
 #endif
