@@ -1,4 +1,4 @@
-# $Id: DBD.pm,v 1.4 1997/07/18 13:18:19 timbo Exp $
+# $Id: DBD.pm,v 1.6 1997/09/05 19:16:40 timbo Exp $
 #
 # Copyright (c) 1997 Jonathan Leffler and Tim Bunce
 #
@@ -21,8 +21,8 @@ DBI::DBD - DBD Driver Writer's Guide (draft)
 
 =head1 VERSION and VOLATILITY
 
-	$Revision: 1.4 $
-	$Date: 1997/07/18 13:18:19 $
+	$Revision: 1.6 $
+	$Date: 1997/09/05 19:16:40 $
 
 This document is very much a minimal draft which will need to be revised
 frequently (and extensively).
@@ -186,7 +186,7 @@ Driver.h should look like this:
 
   #include "dbdimp.h"
 
-  #include <DBDXSI.h>     /* installed by the DBI module  */
+  #include <dbd_xsh.h>     /* installed by the DBI module  */
 
 
 =head2 Implementation header dbdimp.h
@@ -444,20 +444,28 @@ use DBI ();
 
 $DBI::DBD::VERSION = $DBI::VERSION;
 
-@EXPORT = (dbd_postamble);
+@EXPORT = qw(dbd_edit_mm_attribs dbd_postamble);
+
+
+sub dbd_edit_mm_attribs {
+	my %a = @_;
+
+	return %a;
+}
 
 
 sub dbd_postamble {
     # we must be careful of quotes for Win32 here.
     '
-DBI_DRIVER_XST=$(INSTALLSITEARCH)/auto/DBI/Driver.xst
+DBI_DRIVER_XST_DIR=$(INSTALLSITEARCH)/auto/DBI
+DBI_DRIVER_XST=$(DBI_DRIVER_XST_DIR)/Driver.xst
 
 $(BASEEXT).xs: $(BASEEXT).xsi
 
 $(BASEEXT).c: $(BASEEXT).xsi
 
 $(BASEEXT).xsi: $(INSTALLSITEARCH)/auto/DBI/Driver.xst
-	perl -p -e "s/{DRIVER}/$(BASEEXT)/g" < $(DBI_DRIVER_XST) > $(BASEEXT).xsi
+	perl -p -e "s/~DRIVER~/$(BASEEXT)/g" < $(DBI_DRIVER_XST) > $(BASEEXT).xsi
 ';
 }
 
